j crypto
---------------------------

[![Python 3.7](https://img.shields.io/badge/python-3.7-blue.svg)](https://www.python.org/downloads/release/python-370/)

Helper functions to create and Load RSA private/public keys

Install
------------
```
pip3.7 install j_crypto
```

Use
------------
```
j-cryto-create-pair
```
